@@ -58,7 +58,7 @@ def main(driver=None):
             video = image.find("video")
             img = video.get("src")
             if img:
-                images.append({img: "video"})
+                images.append([img, "video"])
 
 
     usernames_og = soup.find_all("img", {"class": "w-8 h-8 sm:w-10 sm:h-10 rounded-full mr-2 sm:mr-3"})
@@ -99,13 +99,13 @@ def main(driver=None):
     if ai_tags_left:
         if ai_tags_left and ai_tags_right:
             print("Both projects used AI")
-            return [left_project, right_project, devlog_1, time_1, devlog_2, time_2, important_buttons, usernames, left_devlogs, left_stuff, right_stuff, right_devlogs, left_description, right_description, driver, left_button, right_button, tie_button, form_element, submit_button, [True, True]]
+            return [left_project, right_project, devlog_1, time_1, devlog_2, time_2, important_buttons, usernames, left_devlogs, left_stuff, right_stuff, right_devlogs, left_description, right_description, driver, left_button, right_button, tie_button, form_element, submit_button, [True, True], left_images, right_images]
         elif ai_tags_left and not ai_tags_right:
             print("Left AI tag found, but not right")
-            return [left_project, right_project, devlog_1, time_1, devlog_2, time_2, important_buttons, usernames, left_devlogs, left_stuff, right_stuff, right_devlogs, left_description, right_description, driver, left_button, right_button, tie_button, form_element, submit_button, [True, False]]
+            return [left_project, right_project, devlog_1, time_1, devlog_2, time_2, important_buttons, usernames, left_devlogs, left_stuff, right_stuff, right_devlogs, left_description, right_description, driver, left_button, right_button, tie_button, form_element, submit_button, [True, False], left_images, right_images]
     elif ai_tags_right and not ai_tags_left:
         print("right ai tag")
-        return [left_project, right_project, devlog_1, time_1, devlog_2, time_2, important_buttons, usernames, left_devlogs, left_stuff, right_stuff, right_devlogs, left_description, right_description, driver, left_button, right_button, tie_button, form_element, submit_button, [False, True]]
+        return [left_project, right_project, devlog_1, time_1, devlog_2, time_2, important_buttons, usernames, left_devlogs, left_stuff, right_stuff, right_devlogs, left_description, right_description, driver, left_button, right_button, tie_button, form_element, submit_button, [False, True], left_images, right_images]
     else:
         print("No AI tags found")
         return [left_project, right_project, devlog_1, time_1, devlog_2, time_2, important_buttons, usernames, left_devlogs, left_stuff, right_stuff, right_devlogs, left_description, right_description, driver, left_button, right_button, tie_button, form_element, submit_button, [False, False], left_images, right_images]
