@@ -59,38 +59,47 @@ class Screen2(Screen):
         self.left_images = scraper_stuff[21]
         self.right_images = scraper_stuff[22]
         # Devlog widgets
-        self.left_devlog_widgets = [
-            Vertical(
-                Pixels.from_image(Image.open(BytesIO(requests.get(self.left_images[i]).content)))
-                if self.left_images[i][1] == "image"
-                else Button(
-                    "Play Devlog Video",
-                    id=f"play-video-{i}",
-                    classes="play-video-button"
-                ),
+        self.left_devlog_widgets = []
+        for i in range(len(left_devlogs)):
+            widgets = []
+            widgets.append(
                 Static(
                     f"[b]{left_stuff[i]}[/b]\n{left_devlogs[i].text.strip()}",
                     classes="left-quarter-devlogs"
                 )
             )
-            for i in range(len(left_devlogs))
-        ]
-        self.right_devlog_widgets = [
-            Vertical(
-                Pixels.from_image(Image.open(BytesIO(requests.get(self.right_images[i]).content)))
-                if self.right_images[i][1] == "image"
-                else Button(
-                    "Play Devlog Video",
-                    id=f"play-video-{i}",
-                    classes="play-video-button"
-                ),
+            if i < len(self.left_images) and self.left_images[i][1] == "image":
+                image = Image.open(BytesIO(requests.get(self.left_images[i][0]).content))
+                image = image.resize((176, 20))
+                widgets.append(Static(Pixels.from_image(image)))
+            else:
+                widgets.append(Link(
+                    "Play Devlog Video in Browser",
+                    classes="left-quarter-demo",
+                    url=self.left_images[i][0]
+                ))
+            self.left_devlog_widgets.extend(widgets)
+
+        self.right_devlog_widgets = []
+        for i in range(len(right_devlogs)):
+            widgets = []
+            widgets.append(
                 Static(
                     f"[b]{right_stuff[i].strip()}[/b]\n{right_devlogs[i].text.strip()}".replace("•", ""),
                     classes="right-quarter-devlogs"
                 )
             )
-            for i in range(len(right_devlogs))
-        ]
+            if i < len(self.right_images) and self.right_images[i][1] == "image":
+                image = Image.open(BytesIO(requests.get(self.right_images[i][0]).content))
+                image = image.resize((176, 20))
+                widgets.append(Static(Pixels.from_image(image)))
+            else:
+                widgets.append(Button(
+                    "Play Devlog Video",
+                    url=self.right_images[i][0],
+                    classes="right-quarter-demo"
+                ))
+            self.right_devlog_widgets.extend(widgets)
         yield Horizontal(
             VerticalScroll(
                 Label(self.left_project, classes="left-quarter"),
@@ -165,14 +174,6 @@ class Screen2(Screen):
                 self.app.push_screen(Screen2())
             else:
                 print("Please enter your feedback before submitting.")
-    def on_button_pressed(self, event: Button.Pressed) -> None:
-        if event.button.id and event.button.id.startswith("play-video-"):
-            _, side, index = event.button.id.split("-")
-            index = int(index)
-            video_url = (
-                self.left_images[index][0] if side == "left" else self.right_images[index][0]
-            )
-            subprocess.run(["mpv", video_url])
 class Voting(App):
     SCREENS = {"screen_one": Screen1, "screen_two": Screen2}
 
